#include <ros/ros.h>

#include <geometry_msgs/Twist.h>
#include <turtlesim/Pose.h>

bool stop = false;

double distance_traveled = 0.0;

turtlesim::Pose p;
bool have_last_p = false;

void poseCB(const turtlesim::Pose::ConstPtr& msg){
	
	if (!stop && msg->x > 10.5){
		ROS_INFO("We are about to hit the wall!!!");
		stop = true;
	}
	
	//compute travel from last time
	if (have_last_p){
		double d = sqrt( (msg->x - p.x)*(msg->x - p.x) + (msg->y - p.y)*(msg->y - p.y) );
		distance_traveled += d;
		
		ROS_INFO("I have travelled %f",distance_traveled);
		
	}
	
	p = *msg;
	have_last_p = true;
	
}

int main(int argc, char **argv){
	ros::init(argc, argv, "turtle_node");
	ros::NodeHandle n;
	
	ros::Publisher velocity_pub = n.advertise<geometry_msgs::Twist>("/turtle1/cmd_vel", 10);
	
	ros::Subscriber pose_sub = n.subscribe("/turtle1/pose", 10, poseCB);
  
	
	
	
	ros::Rate loop_rate(10);
	
	double current_ang_vel = 0.0;
	
	while (ros::ok()){
		geometry_msgs::Twist msg;
		
		if (!stop){
			msg.linear.x = 0.75;
		}
		else {
			msg.linear.x = 0.0;
		}

		
		current_ang_vel += 0.05;
		msg.angular.z = current_ang_vel;

		//publish the message
		velocity_pub.publish(msg);

		//collect messages
		ros::spinOnce();
		
		//sleep to maintain framerate
		loop_rate.sleep();
	}
	
	
	
	
	
	return 0;
}
